pub enum Base58Error {
Empty,
InvalidChar,
InvalidLength,
}Expand description
Errors from base58 decoding a string into a Pubkey.
Variants
Empty
The input string was empty.
InvalidChar
The input contained a character outside the Bitcoin base58 alphabet
(excludes 0, O, I, l).
InvalidLength
The input decoded to a byte stream that is not exactly 32 bytes long.